[][src]Enum texture_synthesis::Error

pub enum Error {
    Image(ImageError),
    InvalidRange(InvalidRange),
    SizeMismatch(SizeMismatch),
    ExampleGuideMismatch(u32u32),
    Io(Error),
    UnsupportedOutputFormat(String),
    NoExamples,
    MapsCountMismatch(u32u32),
}

Variants

Image(ImageError)

An error in the image library occurred, eg failed to load/save

InvalidRange(InvalidRange)

An input parameter had an invalid range specified

SizeMismatch(SizeMismatch)

When using inpaint, the input and output sizes must match

ExampleGuideMismatch(u32u32)

If more than 1 example guide is provided, then all examples must have a guide

Io(Error)

Io is notoriously error free with no problems, but we cover it just in case!

UnsupportedOutputFormat(String)

The user specified an image format we don't support as the output

NoExamples

There are no examples to source pixels from, either because no examples were added, or all of them used SampleMethod::Ignore

MapsCountMismatch(u32u32)