[][src]Struct texture_synthesis::CoordinateTransform

pub struct CoordinateTransform { /* fields omitted */ }

Methods

impl<'a> CoordinateTransform[src]

pub fn apply<E: Into<ImageSource<'a>>, I: IntoIterator<Item = E>>(
    &self,
    source: I
) -> Result<RgbaImage, Error>
[src]

Applies the coordinate transformation from new source images. Important to ensure that you have same number and sizes of the images as during synthesis where the coordinate transform was saved from