[−][src]Enum texture_synthesis::Error
Variants
Image(ImageError)An error in the image library occurred, eg failed to load/save
An input parameter had an invalid range specified
When using inpaint, the input and output sizes must match
If more than 1 example guide is provided, then all examples must have a guide
Io(Error)Io is notoriously error free with no problems, but we cover it just in case!
UnsupportedOutputFormat(String)The user specified an image format we don't support as the output
There are no examples to source pixels from, either because no examples were added, or all of them used SampleMethod::Ignore